use btconsole::{ServerConfig, start_server};
use btlib::{Result, log::BuilderExt};
use std::{
    net::SocketAddr,
    path::PathBuf,
};

const DEFAULT_LOG_LEVEL: &str = "info";

#[tokio::main]
async fn main() -> Result<()> {
        if std::env::var("RUST_LOG").is_err() {
            std::env::set_var("RUST_LOG", DEFAULT_LOG_LEVEL)
        }
        env_logger::Builder::from_default_env().btformat().init();

        let addr = SocketAddr::from(([127, 0, 0, 1], 3000));
        let dist_path = PathBuf::from("../../target/dist");
        let config = ServerConfig::new(addr, dist_path);
        let mut server = start_server(config).await.unwrap();
        let mut signal = Some(server.take_shutdown_signal().unwrap());
        ctrlc::set_handler(move || {
            signal.take().map(|tx| tx.send(()).expect("failed to send shutdown signal"));
        }).expect("failed to install the CTRL-C handler");

        server.has_shutdown().await
}